==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtnumberHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "put the sequential number"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "list of attributes"
#define KEYC "a list of attributes which determines the key of an input file (when -k is omitted, all lines are assumed to take the same key value)."

/*-s*/
#define SRTT "a list of atributes to be rearranged"
#define SRTC "this determines the ordering of records for those having the same key value"
#define SRTF "numerical order, decreasing order"

/*-B*/
#define BKYT "assign sequential number to each distinct key"
#define BKYC "sequential numbering is done for distinct key values. If -S is omitted, sequential numbering is done for lines with the same key value."

/*-S*/
#define BGNT "start number"
#define BGNC "start number (default value is 1)."

/*-I*/
#define INTT "interval"
#define INTC "interval of sequential numbering (default value is 1)."

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "Letting the key of an input file be defined by the attributes specified by -k, the command sequentially numbers the lines which have the same key value. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtnumber -k date -a sequential number -i dat.xt -o rsl.xt\n\
xtnumber -a sequential number -i dat.xt -o rsl.xt\n\
xtnumber -k date -a sequential number -B -i dat.xt -o rsl.xt\n\
xtnumber -k date -a sequential number -S 10 -I 5 -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/en/xtnumberHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "append the sequential number"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "list of attributes"
#define KEYC "a list of attributes which determines the key of an input file (when -k is omitted, all lines are assumed to take the same key value)."

/*-s*/
#define SRTT "a list of atributes to be rearranged"
#define SRTC "this determines the ordering of records for those having the same key value"
#define SRTF "numerical order, decreasing order"

/*-B*/
#define BKYT "assign sequential number to each distinct key"
#define BKYC "sequential numbering is done for distinct key values. If -S is omitted, sequential numbering is done for lines with the same key value."

/*-S*/
#define BGNT "start number"
#define BGNC "start number (default value is 1)."

/*-I*/
#define INTT "interval"
#define INTC "interval of sequential numbering (default value is 1)."

/*-e*/
#define SAMT "Ʊ̤νˡ"
#define SAMC "Ʊ쥭Ʊ쥽ȹͤؤνˡꤹ"
#define SAMS "Ϣ,Ʊֹ,ƱֹǹԿʬå"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "This command sequentially numbers the records with the same key value. If -k is not specified, all records are taken into account with the same key value. The sequential numbers will be stored in as a new attribute defined at -a. The starting value and the interval of the numbering sequence can be defined at the -S and -I argument. Sequential numbering for records with distinct key values classifies them into numeric groups with the -B paramenter. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtnumber -k date -a sequential number -i dat.xt -o rsl.xt\n\
xtnumber -a sequential number -i dat.xt -o rsl.xt\n\
xtnumber -k date -a sequential number -B -i dat.xt -o rsl.xt\n\
xtnumber -k date -a sequential number -S 10 -I 5 -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
